<?php
/**
 * $Horde: ansel/config/styles.php.dist,v 1.6.2.2 2009-06-15 17:16:48 mrubinsk Exp $
 *
 * Configuration for the available gallery style
 *
 * Each entry *must* have:
 *
 * 'name'        =  The internal name of the style (this should match the
 *                  hash key).
 *
 * 'title'       =  This is the title to be displayed to the users.
 *
 * 'thumbstyle'  =  This is the type of thumbnail to use. This must match
 *                  an available Ansel_ImageView object in lib/ImageView.
 *
 * 'background'  =  The desired background color of the style. This will
 *                  set the background of both the photo display area inside
 *                  of Ansel as well as the background color of any generated
 *                  photos. This is useful for installations not using PNG.
 *
 * The following are optional:
 *
 * requires_png               =  Specifies that the style should only be
 *                               available if both the Horde install uses PNG
 *                               photos *and* the currently requesting browser
 *                               has PNG transparency support.
 *
 * default_galleryimage_type  =  How to represent each gallery's default photo.
 *                               This must match an available Ansel_ImageView
 *                               object in lib/ImageView
 *                          create_serialized_styles.php
 * gallery_view               =  The Ansel_View_* subclass to use for gallery
 *                               views.
 *
 * widgets                    =  An array describing any Ansel_Widgets to
 *                               display on this gallery along with any
 *                               parameters the widget may need.
 *
 * hide                      =   Hide this style in the gallery propery page.
 *
 * falback                   -   Fall back to this gallery style if unable to
 *                               use this style (like if we don't have PNG
 *                               support)
 */

// Just a time saver...
$widgets = array('Actions' => array(),
                 'Tags' => array('view' => 'gallery'),
                 'OtherGalleries' => array(),
                 'Geodata' => array(),
                 'Links' => array(),
                 'GalleryFaces' => array(),
                 'OwnerFaces' => array());


$styles['ansel_default'] = array(
    'name' => 'ansel_default',
    'title' => _("Default"),
    'thumbstyle' => 'thumb',
    'background' => 'none',
    'widgets' => $widgets,
);

$styles['ansel_prettythumbs'] = array(
    'name' => 'ansel_prettythumbs',
    'title' => _("Pretty Thumbnails (No Background)"),
    'thumbstyle' => 'prettythumb',
    'requires_png' => true,
    // This really only looks good with ImageMagick, not GD.
    'default_galleryimage_type' => 'roundedstack',
    'background' => 'none',
    'widgets' => $widgets,
);

$styles['ansel_blackonwhite'] = array(
    'name' => 'ansel_blackonwhite',
    'title' => _("Pretty Thumbnails (White Background)"),
    'default_galleryimage_type' => 'roundedstack',
    'thumbstyle' => 'prettythumb',
    'background' => 'white',
    'widgets' => $widgets,
);

$styles['ansel_sharpshadowed'] = array(
    'name' => 'ansel_sharpshadowed',
    'title' => _("Shadowed Thumbnails (White Background)"),
    'thumbstyle' => 'shadowsharpthumb',
    'background' => 'white',
    'default_galleryimage_type' => 'plainstack',
    'widgets' => $widgets
);

/* Polaoid style thumbnails and stacks */
$styles['ansel_polaroid'] = array(
    'name' => 'ansel_polaroid',
    'title' => _("Polaroid Style Thumbnails (White Background)"),
    'thumbstyle' => 'polaroidthumb',
    'background' => 'white',
    'default_galleryimage_type' => 'polaroidstack',
    'widgets' => $widgets,
);

/* Lightbox image views */
$styles['ansel_lightbox'] = array(
    'name' => 'ansel_lightbox',
    'title' => _("A Lightbox Inspired Style (White Background)"),
    'thumbstyle' => 'thumb',
    'background' => 'white',
    'gallery_view' => 'GalleryLightbox',
    'widgets' => $widgets,
);


/* Lightbox image views with no background
 * (requires PNG) */
$styles['ansel_lightbox_png'] = array(
    'name' => 'ansel_lightbox_png',
    'title' => _("A Lightbox Inspired Style (No Background)"),
    'thumbstyle' => 'thumb',
    'background' => 'none',
    'requires_png' => true,
    'gallery_view' => 'GalleryLightbox',
    'widgets' => $widgets,
);

/* Lightbox image views with no background and shadowed thumbs
 * (requires PNG) */
$styles['ansel_lightbox_shadowed_png'] = array(
    'name' => 'ansel_lightbox_shadowed_png',
    'title' => _("A Lightbox Inspired Style (Drop Shadows, No Background)"),
    'thumbstyle' => 'shadowsharpthumb',
    'background' => 'none',
    'requires_png' => true,
    'gallery_view' => 'GalleryLightbox',
    'widgets' => $widgets,
    'fallback' => 'ansel_lightbox'
);


/* Same as above, but with Polaroid thumbnails/stacks
 * and no background (so required png support) */
$styles['ansel_lightbox_polaroid'] = array(
    'name' => 'ansel_lightbox_polaroid',
    'title' => _("Lightbox with Polaroids (No Background)"),
    'thumbstyle' => 'polaroidthumb',
    'background' => 'none',
    'requires_png' => true,
    'default_galleryimage_type' => 'polaroidstack',
    'gallery_view' => 'GalleryLightbox',
    'widgets' => $widgets,
);

/* Simple styles with no Ansel_Widgets useful for rendering  on external sites
 * via the API. Note that some require PNG support, but fallback to ansel_simple
 * if no PNG support is found. You could also create your own simple style with
 * no PNG support required and an appropriate background color for your site
 * indicated */
$styles['ansel_simple'] = array(
    'name' => 'ansel_simple',
    'title' => _("Simple"),
    'thumbstyle' => 'thumb',
    'background' => 'none',
    'hide' => true,
);

/* An API friendly lightbox style */
$styles['ansel_lightbox_simple'] = array(
    'name' => 'ansel_lightbox_simple',
    'title' => _("Simple Lightbox"),
    'thumbstyle' => 'thumb',
    'background' => 'none',
    'requires_png' => true,
    'gallery_view' => 'GalleryLightbox',
    'hide' => true,
    'fallback' => 'ansel_simple'
);

/* Same as above, but with polaroid thumbnails */
$styles['ansel_lightbox_simple_polaroid'] = array(
    'name' => 'ansel_lightbox_polaroid',
    'title' => _("Lightbox with Polaroids (No Background)"),
    'thumbstyle' => 'polaroidthumb',
    'background' => 'none',
    'requires_png' => true,
    'default_galleryimage_type' => 'polaroidstack',
    'gallery_view' => 'GalleryLightbox',
    'hide' => true,
    'fallback' => 'ansel_simple'
);
